Communication channels
======================

Discord
-------
We would be very happy if you got in touch with us, so please don't hesitate!
The easiest way is to join our Discord channel. There we can reply more or less
instantly. The #tonic channel is part of SynSense's public space along other channels
for all things revolving around SNN training.
The link to join is https://discord.gg/V6FHBZURkg.

Github
------
If Discord is not an option, you can always start a discussion on Github 
`here <https://github.com/neuromorphs/tonic/discussions>`_ or open an issue. It's 
good practice to keep the discussion public, since other people will likely run into
similar issues or have similar questions. 
